@@ -146,7 +146,7 @@ class BoardInterface:
         },
         "litex_sim": {
             "description": "LiteX SoC running on Verilated simulation",
-            "arch": "rv32i",
+            "arch": "rv32imc",
             "no_attribute_table": True,
             "flash_file": {
                 # This corresponds to the --integrated-rom-size when starting
@@ -154,6 +154,18 @@ class BoardInterface:
                 "max_size": 0x00100000,
             },
         },
+        "qemu_rv32_virt": {
+            "description": "QEMU RISC-V 32 bit virt Platform",
+            "arch": "rv32imac",
+            # The QEMU-provided binary will be loaded at address 0x80000000
+            "address_translator": lambda addr: addr - 0x80000000,
+            "no_attribute_table": True,
+            "flash_file": {
+                # Size of the ROM and PROG region combined, where the resulting
+                # binary will be loaded into by QEMU:
+                "max_size": 0x00200000,
+            },
+        },
         "stm32f3discovery": {
             "description": "STM32F3-based Discovery Boards",
             "arch": "cortex-m4",
@@ -250,6 +262,17 @@ class BoardInterface:
                            source [find target/rp2040.cfg];",
             },
         },
+        "sma_q3": {
+            "description": "SMA Q3 smart watch (Bangle.js 2, Jazda)",
+            "arch": "cortex-m4",
+            "page_size": 4096,
+            "no_attribute_table": True,
+            "openocd": {
+                "prefix": "source [find interface/stlink.cfg]; \
+                           interface hla; \
+                           source [find target/nrf52.cfg];",
+            },
+        },
     }
 
     def __init__(self, args):
