@@ -327,7 +327,7 @@ def command_inspect_tab(args):
 
         # Ask the user if they want to see more detail about a certain TBF.
         tbf_names = tab.get_tbf_names()
-        index = helpers.menu(
+        index = helpers.menu_new(
             tbf_names + ["None"],
             return_type="index",
             title="Which TBF to inspect further?",
@@ -567,6 +567,16 @@ def main():
         help="Tell Tockloader to assume the bootloader is already active.",
     )
 
+    # Parser for all output formatting related flags shared by multiple
+    # commands.
+    parent_format = argparse.ArgumentParser(add_help=False)
+    parent_format.add_argument(
+        "--output-format",
+        help="Address where apps are located",
+        choices=["terminal", "json"],
+        default="terminal",
+    )
+
     # Support multiple commands for this tool
     subparser = parser.add_subparsers(title="Commands", metavar="")
 
@@ -598,6 +608,12 @@ def main():
         default=None,
         help="Specify the board that is being read from. Only used with --rtt.",
     )
+    listen.add_argument(
+        "--jlink", action="store_true", help="Use JLinkExe. Only used with --rtt."
+    )
+    listen.add_argument(
+        "--openocd", action="store_true", help="Use OpenOCD. Only used with --rtt."
+    )
     listen.add_argument(
         "--jlink-cmd", help="The JLinkExe binary to invoke. Only used with --rtt."
     )
@@ -620,6 +636,29 @@ def main():
         default="swd",
         help="The interface type to pass to JLinkExe. Only used with --rtt.",
     )
+    listen.add_argument(
+        "--openocd-board",
+        help="The cfg file in OpenOCD `board` folder. Only used with --rtt.",
+    )
+    listen.add_argument(
+        "--openocd-cmd",
+        default="openocd",
+        help="The openocd binary to invoke. Only used with --rtt.",
+    )
+    listen.add_argument(
+        "--openocd-options",
+        default=[],
+        help="Tockloader-specific flags to direct how Tockloader uses OpenOCD. Only used with --rtt.",
+        nargs="*",
+    )
+    listen.add_argument(
+        "--openocd-commands",
+        default={},
+        type=lambda kv: kv.split("=", 1),
+        action=helpers.ListToDictAction,
+        help='Directly specify which OpenOCD commands to use for "program", "read", or "erase" actions. Example: "program=flash write_image erase {{binary}} {address:#x};verify_image {{binary}} {address:#x};" Only used with --rtt.',
+        nargs="*",
+    )
     listen.set_defaults(func=command_listen)
 
     install = subparser.add_parser(
@@ -664,7 +703,7 @@ def main():
 
     listcmd = subparser.add_parser(
         "list",
-        parents=[parent, parent_apps, parent_channel],
+        parents=[parent, parent_apps, parent_channel, parent_format],
         help="List the apps installed on the board",
     )
     listcmd.set_defaults(func=command_list)
@@ -680,7 +719,7 @@ def main():
 
     info = subparser.add_parser(
         "info",
-        parents=[parent, parent_apps, parent_channel],
+        parents=[parent, parent_apps, parent_channel, parent_format],
         help="Verbose information about the connected board",
     )
     info.set_defaults(func=command_info)
@@ -795,7 +834,7 @@ def main():
 
     listattributes = subparser.add_parser(
         "list-attributes",
-        parents=[parent, parent_channel],
+        parents=[parent, parent_channel, parent_format],
         help="List attributes stored on the board",
     )
     listattributes.set_defaults(func=command_list_attributes)
