@@ -9,7 +9,7 @@ import tempfile
 import textwrap
 import urllib.request
 
-import pytoml
+import toml
 
 from .app_tab import TabApp
 from .app_tab import TabTbf
@@ -53,7 +53,8 @@ class TAB:
 
     def extract_app(self, arch):
         """
-        Return a `TabApp` object from this TAB. You must specify the desired MCU
+        Return a `TabApp` object from this TAB, or `None` if the requested
+        architecture is not present in the TAB. You must specify the desired MCU
         architecture so the correct App object can be retrieved. Note that an
         architecture may have multiple TBF files if the app is compiled for a
         fixed address, and multiple fixed address versions are included in the
@@ -69,6 +70,10 @@ class TAB:
                 if name_pieces[0] == arch:
                     matching_tbf_filenames.append(contained_file)
 
+        if len(matching_tbf_filenames) == 0:
+            # No match for this architecture! Just return None.
+            return None
+
         # Get all of the TBF headers and app binaries to create a TabApp.
         tbfs = []
         for tbf_filename in matching_tbf_filenames:
@@ -262,7 +267,7 @@ class TAB:
         # Otherwise parse f.toml file.
         metadata_tarinfo = self.tab.getmember("metadata.toml")
         metadata_str = self.tab.extractfile(metadata_tarinfo).read().decode("utf-8")
-        self.metadata = pytoml.loads(metadata_str)
+        self.metadata = toml.loads(metadata_str)
         return self.metadata
 
     def _get_metadata_key(self, key):
