@@ -19,6 +19,7 @@ import textwrap
 import time
 
 from . import helpers
+from . import display
 from .app_installed import InstalledApp
 from .app_padding import PaddingApp
 from .app_padding import InstalledPaddingApp
@@ -107,6 +108,7 @@ class TockLoader:
             "litex_sim": {"start_address": 0x00080000},
             "nucleof4": {"start_address": 0x08040000},
             "microbit_v2": {"start_address": 0x00040000},
+            "qemu_rv32_virt": {"start_address": 0x80100000},
             "stm32f3discovery": {"start_address": 0x08020000},
             "stm32f4discovery": {"start_address": 0x08040000},
             "raspberry_pi_pico": {"start_address": 0x10020000},
@@ -249,7 +251,13 @@ class TockLoader:
             # Get all apps based on their header
             apps = self._extract_all_app_headers(verbose)
 
-            self._print_apps(apps, verbose, quiet)
+            if self.args.output_format == "json":
+                displayer = display.JSONDisplay()
+            else:
+                displayer = display.HumanReadableDisplay()
+
+            displayer.list_apps(apps, verbose, quiet)
+            print(displayer.get())
 
     def install(self, tabs, replace="yes", erase=False, sticky=False):
         """
@@ -526,7 +534,15 @@ class TockLoader:
                     "No bootloader found! That means there is nowhere for attributes to go."
                 )
 
-            self._print_attributes(self.channel.get_all_attributes())
+            attributes = self.channel.get_all_attributes()
+
+            if self.args.output_format == "json":
+                displayer = display.JSONDisplay()
+            else:
+                displayer = display.HumanReadableDisplay()
+
+            displayer.list_attributes(attributes)
+            print(displayer.get())
 
     def set_attribute(self, key, value):
         """
@@ -595,25 +611,27 @@ class TockLoader:
         # Enter bootloader mode to get things started
         with self._start_communication_with_board():
 
+            if self.args.output_format == "json":
+                displayer = display.JSONDisplay()
+            else:
+                displayer = display.HumanReadableDisplay(show_headers=True)
+
             # Print all apps
-            print("Apps:")
             apps = self._extract_all_app_headers()
-            self._print_apps(apps, True, False)
+            displayer.list_apps(apps, True, False)
 
             if self._bootloader_is_present():
                 # Print all attributes
-                print("Attributes:")
                 attributes = self.channel.get_all_attributes()
-                self._print_attributes(attributes)
-                print("")
+                displayer.list_attributes(attributes)
 
                 # Show bootloader version
                 version = self.channel.get_bootloader_version()
                 if version == None:
                     version = "unknown"
-                print("Bootloader version: {}".format(version))
-            else:
-                print("No bootloader.")
+                displayer.bootloader_version(version)
+
+            print(displayer.get())
 
     def dump_flash_page(self, page_num):
         """
@@ -658,7 +676,11 @@ class TockLoader:
         # here. There is no need to save the channel, since
         # `channel.run_terminal()` never returns.
         if self.args.rtt:
-            channel = JLinkExe(self.args)
+            if self.args.openocd:
+                channel = OpenOCD(self.args)
+            else:
+                channel = JLinkExe(self.args)
+
         else:
             channel = BootloaderSerial(self.args)
             channel.open_link_to_board(listen=True)
@@ -920,17 +942,30 @@ class TockLoader:
         # Get where the apps live in flash.
         address = self._get_apps_start_address()
 
-        # First, we are going to split the work into two cases: do we have any
-        # app that is compiled for a fixed address, or not? Likely, there won't
-        # be platforms that have mixed fixed address apps and PIC apps. This
-        # split simplifies things, but a better algorithm would not have this
-        # split.
-        is_fixed_address_app = False
-        for app in apps:
-            if app.has_fixed_addresses():
-                is_fixed_address_app = True
+        # First, we are going to split the work into three cases:
+        #
+        # 1. All apps are fixed address, meaning they have to be loaded at very
+        #    specific addresses.
+        # 2. All apps are position independent, and can be put at any address.
+        # 3. There is a mix of fixed address and position independent apps.
+        #
+        # Then we can handle organizing the apps in each case separately.
 
-        if is_fixed_address_app:
+        # Default to mixed, and only if all are one type be specific.
+        app_position_scenario = "mixed"
+        if all(map(lambda x: x.has_fixed_addresses(), apps)):
+            app_position_scenario = "fixed"
+        elif all(map(lambda x: not x.has_fixed_addresses(), apps)):
+            app_position_scenario = "independent"
+
+        if app_position_scenario == "mixed":
+            # Currently unsupported. This could (should?) be added in the
+            # future.
+            raise TockLoaderException(
+                "Mixing fixed address and position-independent apps is currently unsupported."
+            )
+
+        if app_position_scenario == "fixed":
             #
             # This is the fixed addresses case
             #
@@ -1274,6 +1309,12 @@ class TockLoader:
             # This app is good to install, continue the process.
 
             app = tab.extract_app(arch)
+            if app == None:
+                raise TockLoaderException(
+                    "Unable to locate a valid application binary matching the target architecture ({})".format(
+                        arch
+                    )
+                )
 
             # Enforce other sizing constraints here.
             app.set_size_constraint(self.app_settings["size_constraint"])
@@ -1369,17 +1410,3 @@ class TockLoader:
         else:
             # In quiet mode just show the names.
             print(" ".join([app.get_name() for app in apps]))
-
-    def _print_attributes(self, attributes):
-        """
-        Print the list of attributes in the bootloader.
-        """
-        for index, attribute in enumerate(attributes):
-            if attribute:
-                print(
-                    "{:02d}: {:>8} = {}".format(
-                        index, attribute["key"], attribute["value"]
-                    )
-                )
-            else:
-                print("{:02d}:".format(index))
